/*****************************************************************************
 * Media Library
 *****************************************************************************
 * Copyright (C) 2015-2019 Hugo Beauzée-Luyssen, Videolabs, VideoLAN
 *
 * Authors: Hugo Beauzée-Luyssen <hugo@beauzee.fr>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#pragma once

#include "compat/Mutex.h"
#include <vector>

namespace VLC
{
class Instance;
}

struct libvlc_instance_t;

namespace medialibrary
{

class VLCInstanceCb
{
public:
    virtual ~VLCInstanceCb() = default;
    virtual void onInstanceReplaced( VLC::Instance& ) = 0;
};

class VLCInstance
{
public:
    static VLC::Instance get();
    static void set( libvlc_instance_t* instance );
    static bool isSet();
    static void registerCb( VLCInstanceCb* cb );
    static void unregisterCb( VLCInstanceCb* cb );
private:
    static compat::Mutex s_lock;
    static VLC::Instance s_instance;
    static std::vector<VLCInstanceCb*> s_cbs;
};

}
